pub struct DeviceIdentity {
pub device_id: [u8; 16],
pub public_key: [u8; 32],
/* private fields */
}Expand description
Device identity containing signing keys and derived key agreement keys
Fields
device_id: [u8; 16]Device ID (BLAKE3-16 of Ed25519 public key)
public_key: [u8; 32]Ed25519 public key for signatures
Implementations
Sourceimpl DeviceIdentity
impl DeviceIdentity
Sourcepub fn x25519_public_key(&self) -> [u8; 32]
pub fn x25519_public_key(&self) -> [u8; 32]
Get the X25519 public key for key agreement
Sourcepub fn agree(&self, remote_x25519_public: &[u8; 32]) -> Result<[u8; 32]>
pub fn agree(&self, remote_x25519_public: &[u8; 32]) -> Result<[u8; 32]>
Perform key agreement with a remote public key to derive a shared secret. Returns an error if the DH result is all-zero (low-order point).
Sourcepub fn pair_with(
&self,
remote_public_key: &[u8; 32],
remote_x25519_public: &[u8; 32],
) -> Result<PairedDevice>
pub fn pair_with( &self, remote_public_key: &[u8; 32], remote_x25519_public: &[u8; 32], ) -> Result<PairedDevice>
Pair with a remote device to create a PairedDevice
Sourcepub fn export_seed(&self) -> [u8; 32]
pub fn export_seed(&self) -> [u8; 32]
Export the identity seed (for backup/recovery)