pub struct MerkleTree { /* private fields */ }Expand description
Merkle tree for computing state roots
Implementations
Sourceimpl MerkleTree
impl MerkleTree
Sourcepub fn generate_proof(
&mut self,
leaf_index: usize,
) -> Option<Vec<([u8; 32], bool)>>
pub fn generate_proof( &mut self, leaf_index: usize, ) -> Option<Vec<([u8; 32], bool)>>
Generate a Merkle inclusion proof for the leaf at the given index.
Returns a vector of sibling hashes from leaf to root. Each entry is
(sibling_hash, is_left) where is_left indicates the sibling is on the
left side of the pair.